import bb.cascades 1.0
import bb.system 1.2
import bb.platform 1.2
import org.labsquare 1.0
import bb.cascades.pickers 1.0
import com.sample.payment 1.0

Page {
    id: page
    titleBar: TitleBar {
        title: "The Bing Image of the Day"
    }
    Menu.definition: MenuDefinition {
        // Add a Help action
        helpAction: HelpActionItem {
            title: qsTr("About")
            imageSource: "asset:///images/ic_info.png"
            onTriggered: {
                aboutDialog.show()
            }
        }
        actions: ActionItem {
            title: "Invite"
            imageSource: "asset:///images/ic_bbm.png"
            onTriggered: {
                app.inviteUserToDownloadViaBBM();
            }
        }
        /*settingsAction: SettingsActionItem {
            title: qsTr("Settings")
            onTriggered: {
                settingsView.open();
            }
        }*/
        attachedObjects: [
            SystemDialog {
                id: aboutDialog
                title: "About"
                body: "Daily Wallpaper\n\n©2015 Domisy Dev\nDeveloper - Theodore Mavrakis\n\nIcon by Aslan Vatsaev\n\nSupport - domisydev@gmail.com\nVersion - " + app.getVersion();
            }
        ]
    }
    actions: [
        ActionItem {
            title: "Set Wallpaper"
            imageSource: "asset:///images/setBackgroundIcon.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            onTriggered: {
                app.setImageWallpaper(bingWebImage.url);
            }
        },
        ActionItem {
            title: "Download Image"
            imageSource: "asset:///images/downloadIcon.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            onTriggered: {
                filePicker.open();
            }
            attachedObjects: [
                FilePicker {
                    property string fileName: getDate()
                    id: filePicker
                    type: FileType.Picture
                    title: "Select Location"
                    mode: FilePickerMode.Saver
                    defaultSaveFileNames: [ fileName ]
                    onFileSelected: {
                        console.log("FileSelected signal received : " + selectedFiles);
                        app.downloadImage(selectedFiles[0]);
                    }
                    function getDate() {
                        var date = new Date();
                        date = Qt.formatDateTime(date,'yyyy-MM-dd');
                        return "BingWallpaper-" + date + ".jpg";
                    }
                }
            ]
        },
        ActionItem {
            title: "Refresh"
            imageSource: "asset:///images/reloadIcon.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            onTriggered: {
                shareAction.enabled = false;
                infoAction.enabled = false;
                app.initiateRequest();
            }
        },
        ActionItem {
            title: "Info"
            id: infoAction
            enabled: false
            imageSource: "asset:///images/aboutIcon.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            onTriggered: {
                app.showImageInfoToast();
            }
        },
        InvokeActionItem {
            id: shareAction
            objectName: "shareAction"
            enabled: false
            title: "Share"
            ActionBar.placement: ActionBarPlacement.InOverflow
            query {
                mimeType: "text/plain"
                invokeActionId: "bb.action.SHARE"
            }
            onTriggered: {
                data = "Check out this great wallpaper - " + bingWebImage.url + " from Daily Wallpaper using Bing http://bit.ly/10UI0Gh";
            }
        }
    ]
    Container {
        layout: DockLayout {
        }
        ActivityIndicator {
            objectName: "indicator"
            id: indicator
            verticalAlignment: VerticalAlignment.Center
            horizontalAlignment: HorizontalAlignment.Center
            preferredWidth: 200
            preferredHeight: 200
        }
        WebImageView {
            objectName: "bingImageComponent"
            id: bingWebImage
            preferredHeight: maxHeight - 200
            preferredWidth: maxWidth
            scalingMethod: ScalingMethod.AspectFill
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Center
            onImageChanged: {
                shareAction.enabled = true;
                infoAction.enabled = true;
            }
            gestureHandlers: [
                TapHandler {
                    onTapped: {
                        if (autoToggleContainer.expanded) {
                            hideToggle.play();
                            autoToggleContainer.expanded = false;
                        } else {
                            showToggle.play()
                            autoToggleContainer.expanded = true;
                        }
                    }
                }
            ]
        }
        Container {
            property bool expanded: true
            id: autoToggleContainer
            layout: DockLayout {
            }
            preferredWidth: maxWidth
            bottomPadding: 100
            Container {
                id: colorBackgroundCont
                preferredWidth: maxWidth
                background: Color.DarkGray
                //preferredHeight: 50
                opacity: 0.6
            }
            Container {
                id: cont
                layout: DockLayout {
                }
                preferredWidth: maxWidth
                leftPadding: 10
                rightPadding: 10
                topPadding: 10
                bottomPadding: 10

                Label {
                    textStyle.color: Color.White
                    textStyle.fontSize: FontSize.Large
                    text: "Automatically update"
                    horizontalAlignment: HorizontalAlignment.Left
                    verticalAlignment: VerticalAlignment.Center
                }
                ToggleButton {
                    property bool isTouched
                    horizontalAlignment: HorizontalAlignment.Right
                    id: autoUpdateToggle
                    checked: app.isServiceRunning()
                    onCheckedChanged: {
                        if (isTouched) {
                            if (checked) {
                                if (app.getDigitalGoodOwned()) {
                                    app.setHeadlessStatus(true);
                                    headlessActivatedToast.show();
                                    //app.setAutomaticUpdate(true);
                                } else {
                                    autoUpdateToggle.setChecked(false);
                                    upgradeDialog.show();
                                }
                            } else {
                                app.setHeadlessStatus(false);
                                //app.setAutomaticUpdate(false);
                            }
                        }
                    }
                    onTouch: {
                        isTouched = true;
                    }
                    attachedObjects: [
                        SystemDialog {
                            id: upgradeDialog
                            title: "Upgrade Daily Wallpaper?"
                            body: "In order to enable this feature you must purchase the upgrade for $1.99 USD.\nDaily Wallpaper will automatically update your wallpaper every day without even opening the app! You can toggle this feature on and off as desired."
                            confirmButton.label: "Buy Upgrade"
                            cancelButton.label: "Maybe Later"
                            customButton.label: "Restore Upgrade"
                            onFinished: {
                                if (upgradeDialog.result == SystemUiResult.ConfirmButtonSelection) {
                                    paymentControl.purchase("53100888", "autoupdatewallpaper", "Daily Wallpaper Upgrade");
                                    //rootPaymentManager.requestPurchase("53100888", "autoupdatewallpaper", "Daily Wallpaper Upgrade");
                                } else if (upgradeDialog.result == SystemUiResult.CustomButtonSelection) {
                                    //app.getExistingPurchases(true);
                                    //rootPaymentManager.requestExistingPurchases(true);
                                    paymentControl.getExisting(true);
                                }
                            }
                        },
                        SystemToast {
                            id: headlessActivatedToast
                            body: "Daily Wallpaper is now running in the background... the application will continue to work even after you exit!"
                        }
                    ]
                }
                attachedObjects: [
                    LayoutUpdateHandler {
                        onLayoutFrameChanged: {
                            colorBackgroundCont.preferredHeight = layoutFrame.height
                        }
                    }
                ]
            }
            attachedObjects: [
                TranslateTransition {
                    id: hideToggle
                    toY: -100
                },
                TranslateTransition {
                    id: showToggle
                    toY: 0
                }
            ]
        }
    }
    attachedObjects: [
        PaymentServiceControl {
            id: paymentControl
            property string uid: "53100888"
            property string sku: "autoupdatewallpaper"
            property string name: "Daily Wallpaper Upgrade"
            onPurchaseResponseSuccess: {
                app.setDigitalGoodOwned("true");
                successToast.body = "Upgrade was successfull!";
                successToast.update();
                successToast.show();
            }
            onExistingPurchasesResponseSuccess: {
                if (receiptsString == "(No purchases)"){
                    console.log("existing unable to find receipt")
                    upgradeError.body = "You have not previously purchased the upgrade!";
                    upgradeError.confirmButton.label = "Buy Upgrade";
                    upgradeError.update();
                    upgradeError.show();
                } else {
                    if (receiptsString.indexOf("autoupdatewallpaper") != -1) {
                        app.setDigitalGoodOwned("true");
                        successToast.body = "Upgrade restored successfully!";
                        successToast.update();
                        successToast.show();
                    } else {
                        upgradeError.body = "You have not previously purchased the upgrade!";
                        upgradeError.confirmButton.label = "Buy Upgrade";
                        upgradeError.update();
                        upgradeError.show();
                    }
                    console.log("existing receiptString - " + receiptsString)
                    //already purchased enable content
                }
                console.log("existingPurchaseResponseSuccess - " + receiptsString)
            }
            onInfoResponseError: {
                if (errorText.indexOf("AW30222i") != -1) {
                    app.setDigitalGoodOwned("true");
                    successToast.body = "Upgrade was successfull!";
                    successToast.update();
                    successToast.show();
                } else {
                    upgradeError.body = errorCode + ": " + errorText;
                    upgradeError.confirmButton.label = "Try Again";
                    upgradeError.update();
                    console.log("Error: " + errorText);
                    upgradeError.show();
                }
            }
        },
        /*PaymentManager {
            id: rootPaymentManager
            windowGroupId: Application.mainWindow.groupId
            onPurchaseFinished: {
                if (reply.errorCode == 0) {
                    if (reply.receipt["digitalGoodSku"] == "autoupdatewallpaper") {
                        app.setDigitalGoodOwned("true");
                        successToast.body = "Upgrade was successfull!";
                        successToast.update();
                        successToast.show();
                    }
                } else {
                    upgradeError.body = reply.errorCode + ": " + reply.errorText
                    upgradeError.confirmButton.label = "Try Again";
                    upgradeError.update();
                    console.log("Error: " + reply.errorInfo);
                    upgradeError.show();
                }
            }
            onExistingPurchasesFinished: {
                if (reply.errorCode == 0) {
                    var purchaseFound = false;
                    for (var i = 0; i < reply.purchases.length; i++) {
                        if (reply.purchases[i]["digitalGoodSku"] == "autoupdatewallpaper") {
                            purchaseFound = true;
                        }
                    }
                    if (purchaseFound) {
                        app.setDigitalGoodOwned("true");
                        successToast.body = "Upgrade restored successfully!";
                        successToast.update();
                        successToast.show();
                    } else {
                        upgradeError.body = "You have not previously purchased the upgrade!";
                        upgradeError.confirmButton.label = "Buy Upgrade";
                        upgradeError.update();
                        console.log("Error: " + reply.errorInfo);
                        upgradeError.show();
                    }
                } else {
                    upgradeError.body = reply.errorCode + ": " + reply.errorText
                    upgradeError.confirmButton.label = "Buy Upgrade";
                    upgradeError.update();
                    console.log("Error: " + reply.errorInfo);
                    upgradeError.show();
                }
            }
        },*/
        SystemDialog {
            id: upgradeError
            title: "Upgrade Error"
            onFinished: {
                if (upgradeError.result == SystemUiResult.ConfirmButtonSelection) {
                    paymentControl.purchase("53100888", "autoupdatewallpaper", "Daily Wallpaper Upgrade");
                    //rootPaymentManager.requestPurchase("53100888", "autoupdatewallpaper", "Daily Wallpaper Upgrade");
                }
            }
        },
        SystemToast {
            id: successToast
        }
    ]
    onCreationCompleted: {
        //rootPaymentManager.setConnectionMode(1); //Test=0, Production=1
    }
}
